==> hoteldruid-mod-bg_2.2.0-1.zip: bg/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Датите са грешни"; break;
case "persone":  				$messaggio = "души"; break;
case "La settimana dal":  			$messaggio = "Седмицата от"; break;
case "Il giorno dal":  				$messaggio = "Денят от"; break;
case "al":  					$messaggio = "до"; break;
case "è piena":  				$messaggio = "е запълнен"; break;
case "è pieno":  				$messaggio = "е запълнен"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "<b>Има</b> свободни стаи в избрания период"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", но някои премествания ще трябва да бъдат направени в периоди от<div style=\"display: inline; color: blue;\"> зададено правило 1</div>"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>Няма</b> повече свободни стаи в избрания период"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "Резервацията може да бъде въведена ако се раздели на"; break;
case "parti":  					$messaggio = "части"; break;
case "Periodo di":  				$messaggio = "Период от"; break;
case "dal":  					$messaggio = "от"; break;
case "settimane":  				$messaggio = "седмици"; break;
case "giorni":  				$messaggio = "дни"; break;
case "Tariffa":  				$messaggio = "Тарифа"; break;
case "compresi":  				$messaggio = "включително"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "фиксираните допълнителни плащания"; break;
case "Ricontrolla":  				$messaggio = "Проверете отново"; break;
case "Torna al menù principale":  		$messaggio = "Обратно в главното меню"; break;
case "con la tariffa":  			$messaggio = "с тарифа";
case "Inserisci la prenotazione":  		$messaggio = "Въведете резервация"; break;
case "settimana":  				$messaggio = "седмица"; break;
case "giorno":  				$messaggio = "ден"; break;
case "TOTALE":  				$messaggio = "ОБЩО"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Няма периоди в зададено правило 1 в които е позволено to insert reservations for user"; break;
case "costo aggiuntivo unico":  		$messaggio = "единично допълнително плащане"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "седмично допълнително плащане"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "дневно допълнително плащане"; break;
case "nº di settimane da applicare":  		$messaggio = "nº седмици за кито се отнася"; break;
case "di costi aggiuntivi":  			$messaggio = "на допълнителни плащания"; break;
case "Aggiungi":  				$messaggio = "Добавете"; break;
case "da moltiplicare per":  			$messaggio = "да се умножи по"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "Не беше възможне to apply one or more costs към тарифата"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "tariffa":  				$messaggio = "тарифа"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Преглед на индикативната наличност"; break;
case "potrebbe non essere preciso":  		$messaggio = "може да не е точна"; break;
case "persona":  				$messaggio = "човек"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "per":  					$messaggio = "for"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "nº di giorni da applicare":  		$messaggio = "nº of days to apply"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-bg_3.0.8-1.zip: bg/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Датите са грешни"; break;
case "persone":  				$messaggio = "души"; break;
case "La settimana dal":  			$messaggio = "Седмицата от"; break;
case "Il giorno dal":  				$messaggio = "Денят от"; break;
case "al":  					$messaggio = "до"; break;
case "è piena":  				$messaggio = "е запълнен"; break;
case "è pieno":  				$messaggio = "е запълнен"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "<b>Има</b> свободни стаи в избрания период"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", но някои премествания ще трябва да бъдат направени в периоди от<div style=\"display: inline; color: blue;\"> зададено правило 1</div>"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>Няма</b> повече свободни стаи в избрания период"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "Резервацията може да бъде въведена ако се раздели на"; break;
case "parti":  					$messaggio = "части"; break;
case "Periodo di":  				$messaggio = "Период от"; break;
case "dal":  					$messaggio = "от"; break;
case "settimane":  				$messaggio = "седмици"; break;
case "giorni":  				$messaggio = "дни"; break;
case "Tariffa":  				$messaggio = "Тарифа"; break;
case "compresi":  				$messaggio = "включително"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "фиксираните допълнителни плащания"; break;
case "Ricontrolla":  				$messaggio = "Проверете отново"; break;
case "Torna al menù principale":  		$messaggio = "Обратно в главното меню"; break;
case "con la tariffa":  			$messaggio = "с тарифа";
case "Inserisci la prenotazione":  		$messaggio = "Въведете резервация"; break;
case "settimana":  				$messaggio = "седмица"; break;
case "giorno":  				$messaggio = "ден"; break;
case "TOTALE":  				$messaggio = "ОБЩО"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Няма периоди в зададено правило 1 в които е позволено to insert reservations for user"; break;
case "costo aggiuntivo unico":  		$messaggio = "единично допълнително плащане"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "седмично допълнително плащане"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "дневно допълнително плащане"; break;
case "nº di settimane da applicare":  		$messaggio = "nº седмици за кито се отнася"; break;
case "di costi aggiuntivi":  			$messaggio = "на допълнителни плащания"; break;
case "Aggiungi":  				$messaggio = "Добавете"; break;
case "da moltiplicare per":  			$messaggio = "да се умножи по"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "Не беше възможне to apply one or more costs към тарифата"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "tariffa":  				$messaggio = "тарифа"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Преглед на индикативната наличност"; break;
case "potrebbe non essere preciso":  		$messaggio = "може да не е точна"; break;
case "persona":  				$messaggio = "човек"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "per":  					$messaggio = "for"; break;
case "Disponibilità":  				$messaggio = "Availability"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "nº di giorni da applicare":  		$messaggio = "nº of days to apply"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "non disponibile":  			$messaggio = "not available"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
